function [wqmf] = nm_init(wavelet, parameter, epsilon, res_level)
% function wqmf = nm_init(wavelet, parameter, epsilon, res_level)  
% Code to load operator matrices, convert them to sparse
% non-standard form, and write the results out to a file.
% pfh/ku 4/99
% phubbard@computer.org and umland@math.unm.edu 

% Save starting time
begin_time = clock;
begin_flops = cputime;

sprintf('Function nm_init: Wavelet %s-%d, Epsilon=%f, L=%d', wavelet, ...
	parameter, epsilon, res_level)

% Load operator matrix from file
disp 'Loading left operator'
load oleft.mat

% Compute QMF coeffs
wqmf = MakeONFilter(wavelet, parameter);

% Seems that filter operator not defined for sparse matrices!
disp 'Converting left to dense matrix'
op_left = full(op_left);

disp 'Converting left to sparse NS-form'
ns_l = Mat2SparseNSForm(op_left, res_level, wqmf, epsilon);
disp 'Done with conversion'

per_sparse = ((4096^2 - nnz(ns_l)) / (4096^2)) * 100.0;
sprintf('Left: %d non-zero entries, %f percent sparse', nnz(ns_l), ...
	per_sparse)

% Save, erase from memory
save ns_l.mat ns_l
clear op_left ns_l

disp 'Loading right operator'
load oright.mat

% Seems that filter operator not defined for sparse matrices!
disp 'Converting right to dense matrix'
op_right = full(op_right);

disp 'Converting right to sparse NS-form'
ns_r = Mat2SparseNSForm(op_right, res_level, wqmf, epsilon);
disp 'Done with conversion'

per_sparse = ((4096^2 - nnz(ns_r)) / (4096^2)) * 100.0;
sprintf('Right: %d non-zero entries, %f percent sparse', nnz(ns_r), ...
	per_sparse)

% Save,erase
save ns_r.mat ns_r
clear ns_r or

% Show how hard we worked
end_time = clock;

sprintf('Elapsed time: %s seconds CPU seconds: %d', etime(end_time, begin_time), ...
	(cputime - begin_flops))
